pub struct Item {
pub name: String,
pub lore: String,
pub count: Option<i8>,
pub extra: String,
pub category: String,
pub tier: Rarity,
}Fields
name: StringThe name of an item Does not include minecraft colour codes.
lore: StringThe “lore” of an item, that is, the description of the items. Includes minecraft colour codes.
count: Option<i8>The count of items in the stack
extra: StringField to assist database text searches, it includes enchants and the literal minecraft item’s name
category: StringThe auction category of an item
tier: RarityThe rarity of the item auctioned
Implementations